%%%%%%%Model built in MATLAB 2011b%%%%%%%

clear all
clc
sampletime=5e-6;        %Simulation sample time (s)

%%%%%%%%%%%%%Input circuit%%%%%%%%%%%%%%%
V_utility=11e3;
f_utility=50;           %Utility frequency (Hz)
R_tr=0.01;              %Transformer resistance (pu)
L_tr=0.07;              %Transformer inductance (pu)

%%%%%%%%%%%%%Converter data%%%%%%%%%%%%%%
P_max=4e6;              %Max. power delivered to load (W)
S_conv=1.1*P_max;       %Converter rated power (VA)
I_max=1500;             %Max output current (A)
n_arm=6;                %Number of submodules per leg arm
c_sub=6E-3;             %Submodule capacitor capacitance (F)
m_f=40;                 %Frequency modulation ratio
R_arm=0.01;             %Resistance in arm RL-branch (Ohm)
L_arm=0.001;            %Inductance in arm RL-branch (H)
PF_nom=1;               %Nominal converter operating power factor
Ron=0.00001;            %Submodule switch internal resistance (Ohm)

%%%%%%%%%%%%%%%Load data%%%%%%%%%%%%%%%%%
P_load=4e6;             %Active load power required (W)
PF_50=0.25;             %Load power factor at 50 Hz (inductive)
f_ac=75;                %Output frequency

%%%%%%%%%%%%%%Control%%%%%%%%%%%%%%%%%%%%
dVc_lim=[100, 100, 100; 100, 100, 100];  %Limit for activation of normal switching algorithm (V)
k_pi=0.001;                              %Current control proportional gain
T_ii=0.03;                               %Current controller integrator time
PImax=1;                                 %PI-regulator upper limit (default = 1)
T_filter=0;                              %DC-link filter activation time (s)

%%%%%%%%%%Calculated parameters%%%%%%%%%%%%
R_50=P_max/I_max^2;                      %Load resistance at 50 Hz 
R_load=(0.01125*f_ac+0.439)*R_50; %Frequency dependent load resistance (Ohm)
I_deh=sqrt(P_load/(R_load));   %Required load current to meet power demand (Arms)
Vdc=((sqrt(2)*S_conv/(I_deh))/PF_nom+0.6*I_max*(sqrt((R_arm)^2+(2*pi*f_ac*L_arm)^2))); %Required DC-link voltage (V)
L_load=R_50/(100*pi)*tan(acos(PF_50)); %Load impedance[H]
C_load=1/(2*pi*f_ac)/(2*pi*f_ac*L_load-sqrt(R_load^2/PF_nom^2-R_load^2));
vc_sub_init=Vdc/n_arm;    %Submodule capacitor initial voltage (V)
f_pwm=f_ac*m_f;         %Frequency of pwm-signal (Hz)
T_pwm=1/f_pwm;     %Carrier signal period (s)
Cs=0.5*P_load/(1000*2*pi*50*(Vdc/(1.35*2)^2)); %IGBT snubber capacitance (set to ensure numerical stability)
Rs=4*sampletime/Cs; %IGBT snubber resistance (set to ensure numerical stability)
k_ii=k_pi/T_ii; %Current control integrator gain
C_filter=0.7e-3;%DC-filter capacitance
L_filter=1/(C_filter*(4*pi*f_ac)^2); %DC-filter inductance
R_filter=0.1e-6;
vc_comp_init=0;
